@@ -1,14 +1,14 @@
-#![warn(missing_docs)]
 //!
 //! The basic building blocks for optimization problems.
 //!
 //! [Problem] and [Solver] are the core traits.
 //!
 mod problem;
-mod solver;
+pub mod solver;
 pub mod stop_criterion;
 
-pub use problem::{Objective, Problem};
+#[doc(inline)]
+pub use problem::{Comparison, Evaluation, Objective, Problem};
 
-pub use solver::{Iteration, Solver};
+pub use solver::Solver;
 pub use stop_criterion::StopCriterion;
