@@ -1,16 +1,27 @@
 use std::marker::PhantomData;
 
-use crate::{components::Percentage, core::Problem};
+use crate::core::Problem;
 
 use super::StopCriterion;
 
 /// The execution stops after N iterations.
+#[derive(Debug)]
 pub struct IterCriterion<P> {
     current_iter: usize,
     max_iter: usize,
     _p: PhantomData<P>,
 }
 
+impl<P> Clone for IterCriterion<P> {
+    fn clone(&self) -> Self {
+        Self {
+            current_iter: self.current_iter,
+            max_iter: self.max_iter,
+            _p: self._p,
+        }
+    }
+}
+
 impl<P: Problem> IterCriterion<P> {
     /// Creates a new iteration criterion.
     ///
@@ -25,9 +36,8 @@ impl<P: Problem> IterCriterion<P> {
 }
 
 impl<P: Problem> StopCriterion<P> for IterCriterion<P> {
-    fn progress(&self) -> Percentage {
-        let ratio = self.current_iter as f64 / self.max_iter as f64;
-        unsafe { Percentage::new_unchecked(ratio) }
+    fn progress(&self) -> f64 {
+        self.current_iter as f64 / self.max_iter as f64
     }
 
     fn update(&mut self, _: P::Value) {
