@@ -1,11 +1,9 @@
-use crate::{
-    components::Percentage,
-    core::{Objective, Problem},
-};
+use crate::core::{Objective, Problem, StopCriterion};
 
-use super::StopCriterion;
+use num_traits::{One, Zero};
 
 /// Stops as soon as a target value is reached.
+#[derive(Debug, Clone)]
 pub struct QualityCriterion<P: Problem> {
     target: P::Value,
     done: bool,
@@ -24,11 +22,11 @@ impl<P: Problem> QualityCriterion<P> {
 }
 
 impl<P: Problem> StopCriterion<P> for QualityCriterion<P> {
-    fn progress(&self) -> crate::components::Percentage {
+    fn progress(&self) -> f64 {
         if self.done {
-            Percentage::ONE
+            f64::one()
         } else {
-            Percentage::ZERO
+            f64::zero()
         }
     }
 
@@ -53,10 +51,10 @@ mod tests {
     fn it_works() {
         let mut criterion = QualityCriterion::<()>::new(0);
 
-        assert_ne!(criterion.progress(), Percentage::ONE);
+        assert_ne!(criterion.progress(), f64::one());
 
         criterion.update(0);
 
-        assert_eq!(criterion.progress(), Percentage::ONE);
+        assert_eq!(criterion.progress(), f64::one());
     }
 }
